@@ -21,7 +21,7 @@ eval {
 	require Bio::EnsEMBL::Registry;
 	Bio::EnsEMBL::Registry->import;
 };
-my $VERSION = '1.20';
+my $VERSION = 1.21;
 	
 print "\n A script to fetch genomic annotation from public Ensembl databases\n\n";
 
@@ -236,7 +236,7 @@ $gff_fh->print("# Collected from database $db_name\n");
 
 my $top_level_coordsys = $csa->fetch_all('toplevel') if $csa;
 my $assembly = $top_level_coordsys->[0]->version || undef;
-$gff_fh->print("##genome_build $assembly\n") if $assembly; 
+$gff_fh->print("##genome-build Ensembl $assembly\n") if $assembly; 
 
 
 
