@@ -16,7 +16,7 @@ use Bio::ToolBox::file_helper qw(
 );
 use Bio::ToolBox::db_helper::config;
 use Bio::ToolBox::utility;
-my $VERSION = '1.20';
+my $VERSION = 1.22;
 
 print "\n This program will collect features from a database\n\n";
 
@@ -235,7 +235,9 @@ sub prepare_data_structure_or_output {
 				feature   => 'region', 
 				datasets  => [qw(Chromosome Start End Name Score Strand)],
 			);
-			$Data->bed = 6; # set the bed parameter
+			$Data->bed(6); # set the bed parameter
+			$Data->metadata(1, 'base', 1);
+			$Data->metadata(5, 'strand_style', 'plusminus');
 			
 			# position adjustments
 			if ($start_adj) {
@@ -347,11 +349,11 @@ sub record_bed_feature {
 	# record the feature
 	my @fdata = (
 		$seqfeature->seq_id,
-		$seqfeature->start - 1,
+		$seqfeature->start,
 		$seqfeature->end,
 		$seqfeature->display_name || $seqfeature->primary_id || 'region',
 		$seqfeature->score || 0,
-		$seqfeature->strand, # this will be converted to + or - upon writing
+		$seqfeature->strand || 1, # this will be converted to + or - upon writing
 	);
 	$Data->add_row(\@fdata);
 	
@@ -533,6 +535,9 @@ sub adjust_coordinates {
 		$seqfeature->start($start);
 		$seqfeature->end($end);
 	}
+	
+	# make sure no negative coordinates sneak through
+	$seqfeature->start = 1 if $seqfeature->start < 1;
 }
 
 
